package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````\!]```````!``````````-#)````
M`````````$``.``'`$``&@`9``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````""U````````(+4`````````
M`!````````$````&`````,``````````P%````````#`4```````P`<`````
M``#(#```````````$````````@````8```"@PP```````*##4```````H,-0
M``````#P`0```````/`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````3+0```````!,M$```````$RT0```````U`````````#4``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`#0/`P`80```&@````````````````````)`````````%T```!<````
M6```````````````9@````````!%````6P`````````X````0````#L````.
M````-P```$D```!0````1@```&4``````````````"(```!9````+P````$`
M````````,@```%(````M````80`````````&````&P```&(````<````````
M`"L`````````8````!`````N````7P````````!+````*0````4```!.````
M9````#X```!"````)@```%4````9````9P`````````Q````(0````````!(
M`````````````````````````%$```!$````-0```%<```!>````'P``````
M`````````````%8````S````00```%0```!:````#0`````````/````!```
M`````````````````#D`````````(````!0`````````+````&,`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M`````````````!@`````````$@````,````:````"```````````````"P``
M`````````````````````````````````````````````````"H`````````
M'@`````````*````(P`````````E``````````````````````````(`````
M````````````````````-@``````````````/0``````````````````````
M```Z```````````````D````'0````<````H`````````!$````G````````
M```````_`````````#P```!-````,```````````````-````!<```!,````
M0P`````````3`````````!8```!3````3P``````````````2@```!4`````
M`````````$<`````````````````````````````````````````#````!(`
M```,'$```````(T`````````Y@(``!(````<'$```````)``````````%P``
M`!(````L'$```````)T(````````*0```!$`%P#`QU````````$`````````
M=P,``!(````\'$````````\`````````RP,``!(`#`!P/T```````+X!````
M````0````!$`\?^@PU````````````````````,``!(```!,'$``````````
M````````#0,``!(```!<'$```````#0`````````,P,``!(```!L'$``````
M`%4`````````20```!(```!\'$```````/``````````5P```!(```",'$``
M`````.0`````````8P```!(```"<'$````````\!````````V`,``!(`#``P
M/$````````4`````````=````!$`%P#(QU````````@`````````Z0,``!$`
M$``8P%````````@`````````AP(``!$`%P#0QU```````$``````````?@``
M`!(```"L'$```````*H'````````C0```!$`%P`0R%````````@`````````
M\P,``!(`#`"`.$```````$T`````````EP```!(```"\'$````````H#````
M`````00``!(`#`!@04```````.(`````````00,``!(```#,'$````````(`
M````````[@(``!(```#<'$```````"$`````````)`,``!(```#L'$``````
M`,@,````````I0```!$`%P`8R%````````$`````````,@0``!(`"@#H&T``
M````````````````L@```!(```#\'$```````&$%````````O0```!(````,
M'4```````)``````````R@```!(````<'4```````&$!````````V````!$`
M%P#`S%````````@`````````X````!(````L'4```````,4"````````%0,`
M`!(````\'4```````$P`````````'0,``!(```!,'4``````````````````
M#00``!(`#`"P1$```````*P!````````ZP```!(```!<'4```````&<`````
M````&@0``!(`#`"04$```````%(#````````,`0``!(`#`#P4T```````!0`
M````````+`,``!(```!L'4````````P`````````]0(``!$`$```P%``````
M``@`````````F0,``!(`#`#P'T```````)P`````````:0,``!(```!\'4``
M`````````````````0,``!(```",'4``````````````````2P,``!(```"<
M'4````````H`````````.@,``!(```"L'4```````%0`````````.`0``!(`
M#`!@1D```````"P*````````^@```!(```"\'4```````#L$````````P0(`
M`!(```#,'4``````````````````70(``!(```#<'4```````#$`````````
MSP(``!(```#L'4```````&<`````````100``!(`#`!00D```````&T`````
M````!@,``!(```#\'4```````'P``````````P$``!$`%P`9R%````````$`
M````````4P,``!(````,'D```````'X`````````$0$``!(````<'D``````
M`,X!````````(0$``!$`%P`@R%````````@`````````E`,``!``\?_`QU``
M````````````````;P(``!(````L'D```````$,`````````400``!(`#`#`
M0D```````/`!````````5@0``!(`#`!0/D```````!<!````````:`0``!(`
M#`!@.T```````,D`````````,0$``!$`%P`HR%````````$`````````/`$`
M`!(`#0!T5$``````````````````0@$``!(````\'D```````!\:````````
MN00``!(```!,'D```````!X`````````:@(``!(```!<'D```````)0`````
M````?P(``!(```!L'D```````$H`````````4`$``!(```!\'D```````$(`
M````````9`,``!(```",'D```````"\`````````AP,``!(```"<'D``````
M````````````&P(``!(```"L'D```````#P&````````8`$``!(```"\'D``
M`````"L`````````C0,``!``\?_`QU``````````````````H`(``!(```#,
M'D```````$H`````````:P$``!$`\?^XQ5``````````````````H`,``!``
M\?_(S%``````````````````QP(``!(```#<'D```````&P`````````@0$`
M`!$`%P`IR%````````$`````````C`$``!$`%P`PR%```````!,`````````
MIP(``!$`%P!(R%````````@`````````)P(``!(```#L'D```````"\'````
M````N@(``!(```#\'D``````````````````?@0``!(`#`#0.$```````!X`
M````````FP$``!(````,'T```````'P`````````U0(``!(````<'T``````
M``P`````````F@0``!(`#```(4```````#0`````````L@$``!$`%P!0R%``
M``````@`````````8@,``!(````L'T```````"\`````````IP0``!(`#``P
M04```````"(`````````N`$``!$`%P!8R%````````@`````````F0(``!(`
M```\'T``````````````````PP$``!(```!,'T```````)$"````````T0$`
M`!$`%P!@R%````````@`````````<`,``!(```!<'T```````/0`````````
M?@,``!(```!L'T```````)L`````````90(``!(```!\'T```````&<`````
M````W@$``"``````````````````````````6@,``!(```",'T```````)``
M````````\@$``!(```"<'T```````!4`````````L0(``!(```"L'T``````
M``````````````(``!(```"\'T```````&@!````````#P(``!(```#,'T``
M`````#8`````````(@(``!(```#<'T```````!4``````````&QI8G!E<FPN
M<V\`4&5R;%]C<F]A:P!097)L7W-V7S)P=E]F;&%G<P!03%]P97)L7V1E<W1R
M=6-T7VQE=F5L`%]$64Y!34E#`%!E<FQ?879?<VAI9G0`4&5R;%]M9U]S970`
M4&5R;%]N97=84U]F;&%G<P!03%]C;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?
M<&%R<V5R`%!E<FQ?9&]U;G=I;F0`4$Q?9&]?=6YD=6UP`'!E<FQ?<&%R<V4`
M4&5R;%]N97=35G!V`%!E<FQ?<W9?<V5T<'8`96YV:7)O;@!097)L7VYE=UA3
M`%!E<FQ?<WES7VEN:70S`'!E<FQ?<G5N`%!,7V5X:71?9FQA9W,`8F]O=%]$
M>6YA3&]A9&5R`%!,7V-U<G-T86-K:6YF;P!03%]T86EN=&5D`%]F:6YI`'!E
M<FQ?9&5S=')U8W0`4&5R;%]G=E]F971C:'!V`'!E<FQ?86QL;V,`7T=,3T)!
M3%]/1D93151?5$%"3$5?`%!,7VEN7V5V86P`4$Q?;65M;W)Y7W=R87``4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!03%]O<`!03%]T;W!?96YV`%!E<FQ?879?
M9F5T8V@`4$Q?979A;%]R;V]T`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S
M>7-?=&5R;0!097)L7W-V7W-E='!V;@!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]F<F5E`&QI8FTN<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.`!L
M:6)T:'(N<V\N,P!?7V5R<F]R`')E860`;W!E;@!C;&]S90!L:6)C+G-O+C<`
M;65M;6]V90!?7W-T86-K7V-H:U]G=6%R9`!G971P:60`;65M8W!Y`%]?<W1D
M97)R<`!R96%D;&EN:P!G971U:60`<FUD:7(`<F5A9&1I<@!L<V5E:P!?7W-T
M86-K7V-H:U]F86EL`&9P<FEN=&8`;65M8VAR`%]?<')O9VYA;64`;'-T870`
M<W1R<W1R`'-T<FYC;7``<W1R;F-P>0!U;FQI;FL`<F5A;&QO8P!S=')T;VL`
M<W1R9'5P`&UE;7-E=`!?:6YI=%]T;',`;W!E;F1I<@!S=')C;7``<W!R:6YT
M9@!A=&5X:70`86-C97-S`'-T<FQE;@!E>&5C=G``8VQO<V5D:7(`;6MD:7(`
M7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O
M-2XQ-"XR+VUA8V@O0T]210!P87)?:6YI=%]E;G8`<&%R7V-U<G)E;G1?97AE
M8P!M>5]P87)?<&P`<&%R7V5N=E]C;&5A;@!P87)?9&ER;F%M90!P87)?9FEN
M9'!R;V<`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS7VEN:70`<&%R7VUK=&UP
M9&ER`'!A<E]C;&5A;G5P`&UA:6X`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!P
M87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`1D)31%\Q
M+C`````````"```````"``$``0`"``(``@`````````!`````0`"```````!
M`````0`"``(``@````$``````````0````(``@`!`````0`!``(``0`!``(`
M`@`"``(``0````(``P`"``$``@````(```````$``P`!``$``0````$````"
M``,``@````(``@`"`````0`"``$``0`"```````"``(``@`!`````@`!````
M`@`!`````@```````@`"``,````"`````@```````````````0`!`%$"```0
M````(````+`H>@<```,`P@0````````!``$`=0(``!``````````L"AZ!P``
M`@#"!````````,#'4```````!0````0``````````````,C'4```````!0``
M``\``````````````-#'4```````!0```!$``````````````!#(4```````
M!0```!,``````````````!C(4```````!0```!H``````````````!G(4```
M````!0```#4``````````````"#(4```````!0```#@``````````````"C(
M4```````!0```#X``````````````"G(4```````!0```$X`````````````
M`##(4```````!0```$\``````````````$C(4```````!0```%``````````
M`````%#(4```````!0```%<``````````````%C(4```````!0```%H`````
M`````````&#(4```````!0```%T``````````````-#%4```````!P````$`
M`````````````-C%4```````!P````(``````````````.#%4```````!P``
M``,``````````````.C%4```````!P````4``````````````/#%4```````
M!P````@``````````````/C%4```````!P````D```````````````#&4```
M````!P````H```````````````C&4```````!P````L``````````````!#&
M4```````!P````P``````````````!C&4```````!P````T`````````````
M`"#&4```````!P```!(``````````````"C&4```````!P```!4`````````
M`````##&4```````!P```!<``````````````#C&4```````!P```!@`````
M`````````$#&4```````!P```!D``````````````$C&4```````!P```!P`
M`````````````%#&4```````!P```!T``````````````%C&4```````!P``
M`!X``````````````&#&4```````!P```"```````````````&C&4```````
M!P```"$``````````````'#&4```````!P```"(``````````````'C&4```
M````!P```"0``````````````(#&4```````!P```"<``````````````(C&
M4```````!P```"H``````````````)#&4```````!P```"L`````````````
M`)C&4```````!P```"P``````````````*#&4```````!P```"T`````````
M`````*C&4```````!P```"\``````````````+#&4```````!P```#``````
M`````````+C&4```````!P```#$``````````````,#&4```````!P```#(`
M`````````````,C&4```````!P```#0``````````````-#&4```````!P``
M`#8``````````````-C&4```````!P```#<``````````````.#&4```````
M!P```#H``````````````.C&4```````!P```$```````````````/#&4```
M````!P```$$``````````````/C&4```````!P```$(```````````````#'
M4```````!P```$,```````````````C'4```````!P```$0`````````````
M`!#'4```````!P```$4``````````````!C'4```````!P```$8`````````
M`````"#'4```````!P```$<``````````````"C'4```````!P```$@`````
M`````````##'4```````!P```$H``````````````#C'4```````!P```$T`
M`````````````$#'4```````!P```%$``````````````$C'4```````!P``
M`%(``````````````%#'4```````!P```%0``````````````%C'4```````
M!P```%4``````````````&#'4```````!P```%@``````````````&C'4```
M````!P```%L``````````````'#'4```````!P```%P``````````````'C'
M4```````!P```%X``````````````(#'4```````!P```%\`````````````
M`(C'4```````!P```&```````````````)#'4```````!P```&(`````````
M`````)C'4```````!P```&,``````````````*#'4```````!P```&0`````
M`````````*C'4```````!P```&4``````````````+#'4```````!P```&8`
M`````````````+C'4```````!P```&<``````````````$B#[`CHWP0``.A*
M.```2(/$",,`_S6^J1``_R7`J1``D)"0D/\EOJD0`&@`````Z>#_____);:I
M$`!H`0```.G0_____R6NJ1``:`(```#IP/____\EIJD0`&@#````Z;#_____
M)9ZI$`!H!````.F@_____R66J1``:`4```#ID/____\ECJD0`&@&````Z8#_
M____)8:I$`!H!P```.EP_____R5^J1``:`@```#I8/____\E=JD0`&@)````
MZ5#_____)6ZI$`!H"@```.E`_____R5FJ1``:`L```#I,/____\E7JD0`&@,
M````Z2#_____)5:I$`!H#0```.D0_____R5.J1``:`X```#I`/____\E1JD0
M`&@/````Z?#^____)3ZI$`!H$````.G@_O___R4VJ1``:!$```#IT/[___\E
M+JD0`&@2````Z<#^____)2:I$`!H$P```.FP_O___R4>J1``:!0```#IH/[_
M__\E%JD0`&@5````Z9#^____)0ZI$`!H%@```.F`_O___R4&J1``:!<```#I
M</[___\E_J@0`&@8````Z6#^____)?:H$`!H&0```.E0_O___R7NJ!``:!H`
M``#I0/[___\EYJ@0`&@;````Z3#^____)=ZH$`!H'````.D@_O___R76J!``
M:!T```#I$/[___\ESJ@0`&@>````Z0#^____)<:H$`!H'P```.GP_?___R6^
MJ!``:"````#IX/W___\EMJ@0`&@A````Z=#]____):ZH$`!H(@```.G`_?__
M_R6FJ!``:",```#IL/W___\EGJ@0`&@D````Z:#]____)9:H$`!H)0```.F0
M_?___R6.J!``:"8```#I@/W___\EAJ@0`&@G````Z7#]____)7ZH$`!H*```
M`.E@_?___R5VJ!``:"D```#I4/W___\E;J@0`&@J````Z4#]____)6:H$`!H
M*P```.DP_?___R5>J!``:"P```#I(/W___\E5J@0`&@M````Z1#]____)4ZH
M$`!H+@```.D`_?___R5&J!``:"\```#I\/S___\E/J@0`&@P````Z>#\____
M)3:H$`!H,0```.G0_/___R4NJ!``:#(```#IP/S___\E)J@0`&@S````Z;#\
M____)1ZH$`!H-````.F@_/___R46J!``:#4```#ID/S___\E#J@0`&@V````
MZ8#\____)0:H$`!H-P```.EP_/___R7^IQ``:#@```#I8/S___\E]J<0`&@Y
M````Z5#\____)>ZG$`!H.@```.E`_/___R7FIQ``:#L```#I,/S___\EWJ<0
M`&@\````Z2#\____)=:G$`!H/0```.D0_/__`````%5(B>5!54R-;PA!5%-(
M@^P(BQ](8\.%VTR-9,<03(DEK*P0`'XZ2(M7"$B%TG0Q2(D5VI\0``^V`H3`
M="-(@\(!/"](BP7&GQ``2`]$PDB)!;N?$``/M@)(@\(!A,!UX;B@PU``2(7`
M="M(B??HRO[__[]T5$``Z,#^___H=_O__XG?3(GB3(GNZ$(B``")Q^@'_O__
MZ$+\___KUI"0D)"`/=&G$```54B)Y700ZR202(/`"$B)!66?$`#_TDB+!5R?
M$`!(BQ!(A=)UY,8%I:<0``')PV9F9I!F9F:09F:054B#/=>D$```2(GE=!:X
M`````$B%P'0,O[#%4`!)B</)0?_CR<.0D)"0D)"0D)"0#[8/2(GXA,ET*$B+
M!><U``!(C5<!#[8P2(GX9F:09I!`./$/M@I(#T3"2(/"`83)=>[SPV9F9I!F
M9F:09F9FD$%62(UW.$%505152(G]4TB![`@"``!,C4PDB$V-@8````!,B<](
MBPY(@\8(2(G*2(G(2,'B"$C!X!@E````_X'B``#_`$@)PDB)R$C!Z`@E`/\`
M`$@)PDB)R$C!Z!@E_P```$@)PDB)R$C!Z2A(P>@@2(D72,'@"$B)PDC!X!`E
M````_X'B``#_`$@)PDB)R$C!Z1`E`/\``$@)PD@)RDB)5PA(@\<03#G'#X5U
M____28U):$F-L6@"``!F9I!FD$B+`4@S0=A(,T&H2#-!F$B)PD@!P$C!ZA](
M"<*#XO](B5$82(/!"$@Y\7743(MU`$B+?"2(0;W<O!N/2`-]($B+30A,BU40
M2(MU&$R)\$R)\DV)\4C!X@5(P>@;28G(2`G03(G22<'H`H/@_T@ARDG!Z0)(
MC;P'F7F"6DB)R$C!X1Y(]]!)"<A((?!!@^#_2`-T))!("=!,B<(!QTR)\$PA
M\DCWT$B)^4PAT$C!Z1M,`U0DF$@)PDB)^$C!X`5(C;06F7F"6DB)^D@)P4R)
M\$C!X!X!\4D)P4B)^$B)SD&#X?](]]!(P>X;3"'*3"'`2`G02(G*38V4`IEY
M@EI(B<A(P>`%2`G&2(G(1`'628GZ2/?02<'J`DC!YQY,`T0DH$D)^DPAR$B)
M]T&#XO](P>\;3`-,)*A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$
M`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3`-4)+!,(<)("=!(
MB?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PA
MP$B)SD&#X?](P>X;3"'*2`G02(G*38V4`IEY@EI(B<A(P>`%3`-$)+A("<9(
MB<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,),!,(=)(
M"=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)
MR$PAT$B)^4&#X/](P>D;3`-4),A,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(
M"<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PAP$B)SD&#X?],(<I(P>X;3`-$
M)-!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCW
MT$D)^DPAR$B)]T&#XO](P>\;3`-,)-A,(=)("=!(B?)-C80`F7F"6DB)\$C!
MX`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"
M2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)
M"?%(B<Y!@^'_3`-4).!,(<!,(<I(P>X;3`-$).A("=!(B<I-C90"F7F"6DB)
MR$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;
M3`-,)/!,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>
M2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(
MP>`%2`G!2(GX1`')28GQ2/?02<'I`DC!YAY,`U0D^$D)\4PAP$B)SD&#X?](
MP>X;3`,$)$PARD@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!
MYQY)P>H"2/?028GS20GZ3"'(2(GW08/B_TC![QM,`TPD"$PATD@)T$B)\DV-
MA`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY
M08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(P>8>2<'K`DP#5"00
M2`G!20GS2(GX08/C_T0!R4CWT$PAVDB)SDPAP$F)^4C![AM("=!(P><>2<'I
M`DV-E`*9>8):2(G(3`-$)!A(P>`%20GY2(G*2`G&2(G(08/A_TCWT$PARD0!
MUDPAV$B)]TF)RD@)T$C!X1Y(P>\;38V$`)EY@EI(B?!)P>H"2,'@!4P#7"0@
M20G*2`G'2(GP08/B_TB)\DCWT$0!QTPAR$F)\$PATD@)T$C!YAY)P>@"38V<
M`YEY@EI)"?!(B?I(B?A!@^#_3`-,)"A(P>`%2,'J&T@)PDR)P$PQT$0!VDP#
M5"0P2#'X2(G138V,`:'KV6Y(B=!(P>D;2,'@!4@)P40!R4F)^4C!YQY)P>D"
M2(G.20GY2(G72,'N&T&#X?](P>\"3(G(3#'`3`-$)#A(,=!(P>(>38V4`J'K
MV6Y("==(B<B#Y_](P>`%2`G&2(GX1`'63#'(3`-,)$!(,<A(B?)-C80`H>O9
M;DB)\$C!ZAM(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)
MP$@Q^$@#?"1(2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))
M"?%(B<Y!@^'_2,'N&TR)R$PQP$P#1"102#'02(V\!Z'KV6Y(B<A(P>`%2`G&
M`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD6$@QR$V-A`"A
MZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(
M,?A(`WPD8$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ
M2(G.08/A_TC![AM,B<A,,<!,`T0D:$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^
M2(G72,'B'DC![P)("==(B?*#Y_](B?A,,<A(P>H;3`-,)'!(,<A-C80`H>O9
M;DB)\$C!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X
M2`-\)'A(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)
MSD&#X?](P>X;3(G(3#'`3`.$)(````!(,=!(C;P'H>O9;DB)R$C!X`5("<8!
M_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2(````2#'(38V$
M`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)
MP$@Q^$@#O"20````2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!
MZ0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#A"28````2#'02(V\!Z'KV6Y(B<A(
MP>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`XPDH```
M`$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"28G220G(2(G1
M2<'J`D&#X/](P>D;3(G`2#'X2`.\)*@```!(,?!-C8P!H>O9;DB)T$C!X`5(
M"<%$`<E)B?%(P>8>2<'I`DF)S$D)\4B)SD&#X?](P>X;3(G(3#'`3`.$)+``
M``!(,=!(P>(>2(V\!Z'KV6Y)"=)(B<A!@^+_2,'@!4@)QDR)T`'^3#'(2<'L
M`D@QR$C!X1Y(B?)-C80`H>O9;DD)S$B)\$&#Y/],`XPDN````$C!X`5(P>H;
M2(GS2(N,),@```!("<),B>!(P>L"3#'01`'"3`.4),````!(,?!(P>8>2(G7
M38V,`:'KV6Y("?-(B="#X_](P>`%2,'O&T@)QTB)V$F)TTPQX$0!STG!ZP)(
M,=!(P>(>28GX38V4`J'KV6Y)"=-(B?A!@^/_2,'@!4G!Z!M)"<!,`>E,B=A%
M`=!,B=I,`>%("=A((=I,B<9((?A)B?E(P>X;2`G02,'G'DG!Z0)(`<%,B<!)
M"?E(P>`%08/A_TV)PD@)QDR)R$R)R@'.2(N,)-````!,"=A,(=I,(<!(B?=(
M"=!(P>\;2<'@'DP!Z4G!Z@)!O-;!8LI(`=E-"<)(`<%(B?!!@^+_2,'@!4R)
MTD@)QTR)T`'/2(N,)-@```!,"<A((?!)B?A,`>E,`=E,(<I)B?-("=!(P>8>
M2<'H&T@!P4B)^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"3@````3(G83`G0
M3(G:3(G&3"'22"'X2,'N&TP!Z4@)T$P!R4F)^4C!YQY(`<%,B<!)P>D"2,'@
M!4D)^4@)QD&#X?\!SDB+C"3H````3(G(3`G83(G*2(GW3"':3"'`3`'I2`G0
M3`'138G"2`'!2(GP2,'O&TC!X`5)P>`>2<'J`D@)QTT)P@'/08/B_TB+C"3P
M````3(G03(G228GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!
MYAY(P>`%2<'K`DD)P$D)\T$!R$&#X_](BXPD^````$R)V$R)VDR)QDP)T$PA
MTDC![AM,`>E((?A("=!,`<E)B?E(`<%,B<!(P>`%2`G&`<Y(P><>2<'I`DD)
M^4B+C"0``0``2(GW08/A_TC![QM,B<A,B<I,"=A,(=I,`>E,(<!,`=%-B<)(
M"=!)P>`>2<'J`D@!P4B)\$T)PDC!X`5!@^+_2`G'3(G03(G2`<](BXPD"`$`
M`$P)R$PARD@A\$F)^$@)T$G!Z!M,`>E,`=E)B?-(P>8>2`'!2(GX2<'K`DC!
MX`5)"<!!`<A)"?-(BXPD$`$``$&#X_],B<9,B=A,B=I(P>X;3`G03"'23`'I
M2"'X3`')28GY2`G02,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A_T@)QDR)R$R)
MR@'.2(N,)!@!``!,"=A,(=I,(<!(B?=("=!(P>\;3`'I3`'138G"2<'@'D@!
MP4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,)"`!``!,B=!,B=))B?A,`>E,
M`=E,"<A,(<I((?!)B?-)P>@;2`G02,'F'DG!ZP)(`<%(B?A)"?-(P>`%08/C
M_TD)P$R)V$R)VD$!R$B+C"0H`0``3`G03"'22"'X3(G&2`G02,'N&TP!Z4P!
MR4F)^4C!YQY(`<%,B<!)P>D"2,'@!4D)^4@)QD&#X?\!SDB+C"0P`0``3(G(
M3`G83(G*2(GW3"'`3`'I3`'13"':38G"2`G02<'@'DC![QM(`<%(B?!)P>H"
M2,'@!4T)PD@)QT&#XO\!STB+C"0X`0``3(G03`G(3(G228GX3"'*2"'P2<'H
M&TP!Z4@)T$P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(
MBXPD0`$``$R)V$P)T$R)VDR)QDPATD@A^$P!Z4@)T$P!R4F)^4@!P4R)P$C!
M[AM(P>`%2,'G'DG!Z0)("<9)"?D!SD&#X?](BXPD2`$``$R)R$R)RDB)]TP)
MV$PAVDC![QM,`>E,(<!("=!,`=%-B<)(`<%(B?!)P>`>2,'@!4G!Z@)("<=-
M"<(!ST&#XO](BXPD4`$``$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,
M`=E)B?-(`<%(B?A(P>`%20G`00'(2,'F'DG!ZP))"?-(BXPD6`$``$R)QD&#
MX_](P>X;3(G83(G:3`'I3`G03"'23`')2"'X28GY2`G02,'G'DG!Z0)(`<%)
M"?E,B<!!@^'_3`.L)&`!``!(P>`%2`G&3(G(3(G*3`G83"':`<Y,(<!(B?=(
M"=!-`=5(P>\;20'%2(GP38G"2,'@!4G!X!Y)P>H"2`G'2(N4)&@!``!$`>]-
M"<))B?!!@^+_2(GY2<'H`DR)T$P!XDC!Z1M,,<A,`=I(,?!(P>8>2`'"2(GX
M20GP2,'@!4&#X/]("<%,B<`!T4B+E"1P`0``3#'02#'X2(G.2,'N&TP!XDP!
MRDF)^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)QD&#X?\!UDB+E"1X`0``3(G(
M3#'`2(GW2#'(3`'B3`'228G*2`'"2(GP2,'O&TC!X`5(P>$>2<'J`D@)QTD)
MR@'72(N4)(`!``!!@^+_3(G02(GY3#'(2,'I&TP!XD@Q\$P!PDF)\$C!YAY(
M`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2(`0``3(G`3#'02(G.2#'X
M2,'N&TP!XDP!RDF)^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)Q@'62(N4))`!
M``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"
M2,'@!4D)RD@)QT&#XO\!UTB+E"28`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!
MPDF)\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2@`0``3(G`
M3#'02(G.2#'X2,'N&TP!XDP!RDF)^4@!PDB)R$C!X`5(P><>2<'I`D@)QDD)
M^0'62(N4)*@!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(
M`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"2P`0``3(G03#'(2(GY2#'P
M2,'I&TP!XDP!PDF)\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+
ME"2X`0``3(G`2(G.3`'B3#'02,'N&T@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%
M2<'I`D@)QDD)^0'62(N4),`!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!
MTDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3(`0``3(G0
M3#'(2(GY2#'P2,'I&TP!XDP!PDF)\$@!PDB)^$C!X`5("<%(P>8>2<'H`@'1
M20GP2(N4)-`!``!!@^#_2(G.3(G`2,'N&TP!XDPQT$@Q^$P!RDF)^4@!PDB)
MR$C!YQY(P>`%2<'I`D@)QDD)^0'62(N4)-@!``!!@^'_3(G(2(GW28GS3#'`
M2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!
MUTB+E"3@`0``3(G02(GY2(G[3`'B3`'"3#'(2,'I&T@Q\$G!ZP)(P>8>2`'"
M2(GX20GS2,'@!4&#X_](P>L"2`G!3(G8`=%(BY0DZ`$``$PQT$@Q^$F)R$C!
MYQY)P>@;2`G[3`'B@^/_3`'*28G)2`'"2(G(2,'@!4D)P$B)V$$!T$B+E"3P
M`0``3#'82#'(3(G'3(G&2,'O&TP!XDP!TD@!PDR)P$C!X`5("<<!UTC!X1Y)
MP>D"20G)2(N4)/@!``!(P>X"08/A_TB)^4R)R$C!Z1M,`>)(,=A,`Z0D``(`
M`$PQP$P!VDG!X!Y(`<),"<9(B?A(P>`%@^;_2`G!2(GP20'<3#'(`=%(,?A(
MB<I)`<1(B<A(P>(%2,'H&T@)T$0!X$0!\$B)10!(B?A(P><>2,'H`@--"$@)
M^`-%$`-U&$0#32!(B4T(2(E%$$B)=1A,B4T@2('$"`(``%M=05Q!74%>PTR)
M9"3@3(E\)/A)B?Q(B5PDT$B);"3828GW3(EL).A,B70D\$B#[#A(A?]U)3'`
M2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,-,BS4WE1``387V
M=,\/M@>$P'4$,<#K%SP]2(GZ=/5(@\(!#[8"A,!U18G01"G@28LN2(7M=*5,
M8^A,B?-FD$R)ZDR)YDB)[^B.Y/__A<!U"DF-1"T`@#@]=!I(BVL(2(/#"$B%
M[777Z6____]FD#P]=:SKM4PI\TB#P`%(P?L#08D?Z5;___]F9F:09F:055-(
MB?M(@^P82(UL)!1FD#'`2(GN2(G?Z`/___](A<!T)DAC1"042(T4Q0````!(
M`Q5ZE!``2(/""$B+`DB%P$B)0OAU\.O(2(/$&%M=PY!(@^P8,<!(C70D%.C`
M_O__2(/$&,-F9F:09F9FD&9FD$B#[`B#/96'$`#_=`N+!8V'$`!(@\0(PS'`
MO]E40`#HO/___TB%P'0'#[8`A,!U$S'`B05HAQ``BP5BAQ``2(/$",,\,`^5
MP`^VP.OE9F:02(/L"+______Z-[C__\Q]K_P.$``2(/$".D>YO__9I!(BP4I
MCQ``4S'VOW960`!(BT@(2(L%1H\0``^W4"`/M@44CQ``9H'B_P&#X'_!X@<)
MPF:)40)(BP7SCA``2(M8".C6X___2(E#*$B+!=^.$`!(BU`(2(L%%(\0`$B)
M0C!(BP7)CA``,=)(BT@(2(L%K(X0`$B%P'0'2(N0J````$B)43A(BP6ECA``
M2(M`"$C'0$``````2(L%DHX0`$B+0`A(QT`@`````$B+!7^.$`!(BU`(2(L%
MK(X0`$B)0DA;PV9F9I!F9F:09F:09F:03(ED).A(B5PDV$F)_$B);"3@3(EL
M)/!,B70D^$B![*@```!(A?]T!8`_`'4S2(N<)(````!(BZPDB````$R+I"20
M````3(NL))@```!,B[0DH````$B!Q*@```##9F:0Z'?C__](A<!(B<5TP&9F
MD$B)[^BDY/__2(7`#X2A````2(U8"+_D5$``N0(```#\2(G>\Z9TV;_C5$``
MN0,```!(B=[SIG3(3(GGZ.SD__](B=])B<7HX>3__T&-1`4"2&/XZ"3D__](
MB=E(B<=)B<5,B>*^YE1``#'`Z.SD__](B>9,B>_HX>+__X/``701#[=$)`@E
M`/```#T`0```=#9,B>_H@^+__TR)[^@;Y/__2(GOZ`/D__](A<`/A5____](
MB>_H@N3__TR)Y^C:XO__Z?;^__],B>_HP?[__Y#KQV9F9I!F9F:09F:09F:0
M4TB)^TB#Q(!(B>;H+.'__X7`=1@/MT0D""4`\```/0!```!T#ST`H```=`A(
M@^R`,<!;PTB)W[X"````Z"OB__^%P`^4P$B#[(!;#[;`PY!(B5PDZ$B);"3P
M3(ED)/A(@>PX"```2(V<)!`$``!(BP5+C!``2(F$)!@(```QP.BHX___N8I6
M0`")PK[L5$``,<!(B=_HXN/__X7`>38Q[4B+E"08"```2#,5$8P0`$B)Z'5@
M2(N<)"`(``!(BZPD*`@``$R+I"0P"```2('$.`@``,-(B=^Z``0``$B)YNBX
MX___A<")PWBTC7@!2&/_Z*?B__](A<!TI$ACVTB)Q4B)YDB)VDB)Q^BNXO__
MQ@0K`.N,Z//B__]F9F:09F:0Z2O___]F9F:09F9FD&9FD$%7,<!!5DF)_D%5
M05152(GU4TB#[!B`/CT/E,!(`<5(B>_H]>+__TB-="0408G'3(GW,<#HM_K_
M_TB%P$B)PW0W2(G'Z-/B__]$B?I(.=`/@KP````/MD4`2(/%`8@#2(/#`83`
M=>Y(@\08,<!;74%<05U!7D%?PTB+/0&0$`!%,>2X$````$B#/P!T'TB)^DB+
M0@A!@\0!2(/""$B%P'7O08U$)`)(F$C!X`.+%8Z+$`"%T@^%$`$``$B)Q\<%
M>8L0``$```#HH.'__TB%P$F)Q0^$&0$``$ECQ$B+-9Z/$`!,B>](C1S%````
M`$B)VN@WX?__3(DMA(\0`$B+!7V/$`!(QT0#"`````!$B60D%$$/MA9,B?"$
MT@^%B````(M<)!1%*?=!C7P'`DC!XP-(`QU)CQ``Z##A__](A<!(B0,/A*D`
M``"+5"042(L%+8\0`$B+%-!!#[8&A,"(`G0E/#UT(4R)]^L.9F:09F:02(/'
M`3P]=`X/MD<!2(/"`83`B`)UZL8"/69F9I!F9I`/MD4`2(/%`8A"`4B#P@&$
MP'7MZ;_^__^`^CT/A&____](@\`!#[8(A,D/A&#___^`^3UU[.E6____2(G&
M9F:0Z-?>__](A<!(B06ACA``=!!)8\1(C1S%`````.D+____2(/$&+C_____
M6UU!7$%=05Y!7\-F9F:09F9FD&9FD$%7059)B?Y!54%40;P"54``55-(@^Q(
M3(L]DA@``$F)Y4C'!"0"54``2,=$)`CX5$``2,=$)!`%54``2,=$)!C[5$``
M2,=$)"``54``2,=$)"@254``2,=$)#``````ZQY,B?9,B><QP.B"_?__38ME
M"$F#Q0A-A>0/A(D````QP$R)Y^B'^?__2(7`2(G%=-"`.`!TRTR)]DB)Q^@+
MW___2(7`=<A,B??H7N#__TR)_TB)P^A3X/__2(U<`P%(B>_H1N#__TB-/`/H
MC=___TF)Z$B)QTB)PTR)^4R)\KXQ5D``,<#H4N#__TR)YS'`2(G>Z/G\__]-
MBV4(28/%"$V%Y`^%=____TB#Q$A;74%<05U!7D%?PV9FD&9FD&9FD$B#[#B_
M'55``$B+!5"($`!(B40D*#'`2(L%0A<``$B)!"1(BP4_%P``2(E$)`A(BP4[
M%P``2(E$)!!(BP4W%P``2(E$)!@/MP4S%P``9HE$)"`QP.A'^/__,<"_)E5`
M`.@[^/__,<"_+E5``.@O^/__,<"_-U5``.@C^/__,<"_/E5``.@7^/__,<"_
M3E5``.@+^/__,<"_6E5``.C_]___,<"_V51``.CS]___,<"_8U5``.CG]___
M,<"_;55``.C;]___,<"_=U5``.C/]___,<"_A%5``.C#]___,<"_C55``.BW
M]___,<"_F%5``.C[]___2(7`=`](B<:_8U5``#'`Z,?[__\QP+^I54``Z-OW
M__](A<!T#TB)QK^[54``,<#HI_O__S'`O\950`#HN_?__TB%P'0V2(G&OUI5
M0``QP.B'^___,<"^\E5``+\^54``Z';[__](BT0D*$@S!?J&$`!U44B#Q#C#
M9F:0,<"_UE5``.AT]___2(7`=!%(B<:_V51``#'`Z$#[___KMTB-="01O^=5
M0`"Y"@```/SSIG6C2(UT)!N_V51``#'`Z!G[___KD.CNW?__9I!(@^P(Z,/=
M__^)Q^@,W?__,=)(A<!T`TB+$$B)T$B#Q`C#9F9FD&9F9I!F9I!F9I!54TB)
M^TB#[`A(A?]T"`^V+T"$[7402(/$"+_D5$``6UWIYMK__^C1W?__2`'82(U0
M_T@YTP^#G@```$B+/585```/MD#_#[8W0#CP=`GK*@^V"CC!=69(@^H!2#G3
M9I!R[D@YVG4I0#HO=*I(@\0(6UWIE=K__P^V`D`XQG3C2(/J`4@YTW+OZ]AF
M9I!F9I!(@^H!2#G3<PD/M@(Z!V:0=.Y(*=HQR4B-0@)(/0`$``!V#DB#Q`A(
MB<A;7<.)R.NY2(/"`4B)WK^@R%``Z`K;__^YH,A0`.O:2(L]N!0``.N`9F9F
MD&9F9I!F9I!F9I!(B5PD\$B);"3X2(/L&$B)^^CZ_O__2(G'Z)+>__](B<4Q
MP.@(]O__A<!T"DB%VW0%@#L`=0](BUPD"$B+;"002(/$&,.^]%5``$B)[^A:
MV___2#G%==](B=](BVPD$$B+7"0(2(/$&.D#]___9F:04TB#["")?"0<2(ET
M)!!(C7PD'$B)5"0(2(UT)!!(C50D".AUVO__@#TJA1````^$*0$``(M$)!R`
M#1J%$``#@\`%2&/(2(7)#XA*`0``\D@/*L'R#U@%S7```&8/+@7-<```#X=,
M`0``2(T\S0````#HEMS__TB+="002(G!2(D%<XD0`$R-2?A(BP9(QT$(^55`
M`$B)`4B+!;I\$`!(QT$8_%5``$B)01!$BT0D',<%-XD0``0```!!@_@!?B9,
MC4GXOP$```"Z"````&9FD$B+!!:#QP%(B40*&$B#P@A!.?A_ZT&-0`2^$%1`
M`$4QP$B82<<$P0````"+5"0<2(L]VH@0`(/"`^@NV?__A<")PW1Q2(L]Q8@0
M`.A<VO__,<"_3E5``.AT]/__2(7`=!E(BSVHB!``Z-_;___HFMO__XG82(/$
M(%O#2(L]EX@0`$B%_W1PZ#7^___KU&9FD.B7VO__2(7`2(G'2(D%;H@0`'1T
MZ'/8___&!8"#$```Z:_^__](BSU4B!``Z&O9__^)P^E\____2(G(2(G*2-'H
M@^(!2`G0\D@/*L#R#UC`Z9[^__^^,,A0`+_U5$``,<#HAM?__[]:54``Z-#S
M__](A<!(B<=(B04+B!``#X5S____Z4G___]`MP'HW-G__T%7059!54%428G\
MOUI50`!54TB)\TB![*@$``!(BP7]@A``2(F$))@$```QP.A^\___2(LM#Q(`
M`$R)YTF)Q4B)[N@%V?__2(7`=#E,B>:_=U5``#'`Z#7W__](BY0DF`0``$@S
M%;:"$`!,B>`/A30!``!(@<2H!```6UU!7$%=05Y!7\-,B>?H']K__TR+/;P1
M``!(B=]!B<9,B?[H&MC__TB%P$B)PW2B08/&`42)="0,3(VT))````!F9I!F
MD(`[`+CD5$``2`]$V$V%[70/2(G>3(GOZ(#8__^%P'1^2(G?Z,39__^)P4B8
M#[9$`_\Z10!U'8U!_TB82(T4&)`/MD+_Q@(`@^D!2(/J`3I%`'3MBT0D#`'(
M/?\#```/CRC___]-B>!(B>E(B=J^,59``$R)]S'`Z*#9__](C70D$$R)]^B3
MU___A<!U$0^W1"08)0#P```]`(```'0;,?],B?[H5-?__TB%P$B)PP^%3/__
M_^G3_O__O@$```!,B??H1M?__X7`==1,B?:_=U5``.CY]?__3(GWZ!W6__])
MB<3IM/[__^C`V/__9F9FD$%728G_OUI50`!!5D%505154TB![.B!``!(BP50
M@1``2(F$)-B!```QP$C'A"30````_U5``$C'A"38````!%9``$C'A"3@````
M`````.BM\?__2(7`2(G#=`F`.``/A8\"```QP$B-K"30````Z%WZ__](A<!(
MB<,/A,<!``!(B=_H==C__TB-?``!Z+O7__^`.P!)B<5T)DB)Q69F9I`/MA-(
MB>\QP+X45D``2(/#`4B#Q0+H<MC__X`[`'7A2(VL)*````"_NU5``$C'A"2@
M````NU5``$C'A"2H````M%5``$C'A"2P````&59``$C'A"2X````T55``$C'
MA"3`````(59``$C'A"3(`````````.L12(M]"$B#Q0A(A?\/A$X!```QP.C2
M\/__2(7`2(G#=."`.`!TVTB)Q^AM\___A<!TSTB)W^B]U/__2(7`28G$#X0=
M`0``3(GGZ)G7__],B>](B</HCM?__XV$`P0$``!(8^A(B>_HS-;__TB+%1$/
M``!(B<=)B<9-B>E!N/150`"^+U9``#'`2(G12(E4)!!,B>+H?]?__[[``0``
M3(GWZ(+6__^#P`$/A$@!``!(C70D($R)]^@<U/__A<!U%0^W1"0H)0#P```]
M`$````^$6`$``$F+%TB+/?5_$`!,B?&^2%=``#'`,>WHN-/__TB+E"38@0``
M2#,577\0`$B)Z`^%<P(``$B!Q.B!``!;74%<05U!7D%?PTB)Q^C6T___2(G#
M2(/%"$B%VP^%.?[__TB+?0!(A?\/A#("```QP.BF[___2(7`=-J`.`!URDB#
MQ0A(A=MTV69FD.D*_O__13'D@#U&#0```$C'A"3P````)59``+LE5D``2,>$
M)/@```#D5$``2,>$)``!````````2(VL)/````!U*.FD_O__387D#X6;_O__
M2(M="$B%VP^$CO[__TB#Q0B`.P`/A('^__](B=_HSO'__X7`=-%(B=_H'M/_
M_TF)Q.O$2(G'Z/7T__](B=_H"=/__TB)Q>GY_O__Z&S4__^#.!$/A*K^___H
M7M3__TF+%T2+`$R)\4B+/;I^$`"^"%=``#'`,>WH@-+__^G#_O__BUPD+.A2
MU?__.<,/A9?^__\/MT0D*"7_`0``/<`!```/A8+^__](B>_HW=3__[_[5$``
M2(G%,<#H@N[__TB%P$B)QP^$"P$``.A]TO__28L_2(G&Z+;Z__](A<!)B<0/
MA.\```!,B>?H3M7__X/X`T&)P`^/904``#'`Z%_N__^%P'46,?9,B>?H+=3_
M_X7`B40D'`^%P@```+[R54``O]E40``QP.CT\?__Z.O4__](BTPD$$&)P$&Y
M=E9``$R)\KY15D``2(GO,<`QV^@9U?__ZSKH8M/__X,X$69FD'4_Z+74__](
MBTPD$(/#`4&)P$&)V4R)\KY?5D``2(GO,<!(QP0D=E9``.C=U/__OL`!``!(
MB>_HX-/__X/``72T3(GWZ"/4__](B>Z_6E5``#'`Z&CQ__](B>_H<//__^E_
M_?__NPU60`#I\/O__Y#H)]3__TV+)^D)____N@(```!(Q\;N____B<?HW-+_
M_XM\)!Q(C;0D$`$``+H&````Z%;4__^`O"00`0```'4.@+PD$0$``$,/A-@$
M``"+?"0<,?8QTDR-I"00@0``Z)G2__^_B:O-[[[^W+J8N?#ATL-(QX0D$($`
M``$C16=(B;PD&($``$F#Q#A(B;0D(($``$C'A"0H@0``=E0R$$B)C"0P@0``
M2,>$)#B!````````2,>$)$"!````````QX0DB($```````"+?"0<2(VT)!`!
M``"Z`(```.BMT___A<!!B<4/CCH!``!(BXPD.($``$ECU4B+A"1`@0``2(V<
M)!`!``"---%(.<Y(B;0D.($``$B#T`!(P>H=2(F$)$"!``!(`90D0($``(N4
M)(B!``"%TG1IZ84```!F9I!FD$B+`TB-O"00@0``08/M0$B)A"1(@0``2(M#
M"$F)1"0(2(M#$$F)1"002(M#&$F)1"082(M#($F)1"0@2(M#*$F)1"0H2(M#
M,$F)1"0P2(M#.$B#PT!)B40D..BQU/__08/]/W^;26/52(G>3(GGZ"G2__]$
MB:PDB($``.D)____N$````!(8_I(C;0D$`$``"G028T\/$$YQ8G#00].W4QC
M^TR)^NCRT?__B=@#A"2(@0``@_A`B80DB($```^%QO[__TB-C"00`0``02G=
M2(V\)!"!``!)C1P/Z#'4___I>____XM\)!SH#]'__TB+G"0X@0``3(ND)$"!
M``!(B=A(P>@#@^`_2&/0@\`!@_@XQH042($``(`/CJ<"``!(8_BZ0````#'V
M*<)(C;P\2($``$ACTNA"T/__2(V\)!"!``#HR=/__TB-O"00@0``N0<````Q
MP/Q(@\<X\TBK3(G@2(V\)!"!``!$B*0D@X$``$C!Z!B(G"2'@0``3(V\))"!
M``"(A"2`@0``3(G@3(VL),"!``!(P>@0B(0D@8$``$R)X$V)_$C!Z`B(A"2"
M@0``2(G82,'H&(B$)(2!``!(B=A(P>@0B(0DA8$``$B)V#';2,'H"(B$)(:!
M``#H+=/__TB+E"00@0``2(G0B)0DPX$``$C!Z!B(A"3`@0``2(G02,'H$(B$
M),&!``!(B=!(BY0D&($``$C!Z`B(A"3"@0``2(G0B)0DQX$``$C!Z!B(A"3$
M@0``2(G02,'H$(B$),6!``!(B=!(BY0D(($``$C!Z`B(A"3&@0``2(G0B)0D
MRX$``$C!Z!B(A"3(@0``2(G02,'H$(B$),F!``!(B=!(BY0D*($``$C!Z`B(
MA"3*@0``2(G0B)0DSX$``$C!Z!B(A"3,@0``2(G02,'H$(B$),V!``!(B=!(
MBY0D,($``$C!Z`B(A"3.@0``2(G0B)0DTX$``$C!Z!B(A"30@0``2(G02,'H
M$(B$)-&!``!(B=!(P>@(B(0DTH$``$(/MA0K3(GG,<"^%%9``$B#PP%)@\0"
MZ$#0__](@_L4==[&A"2X@0```$&Y=E9``$V)^$B+3"003(GROD)60`!(B>\Q
MP.@2T/__Z4+[__](F+\X5D``28UT!/RX!0```/Q(B<'SI@^%?OK__T&#^`1T
M&4&-0/Q(BU0D$$B800^V1`3_.@(/A5_Z__])BU\(2(7;#X12^O__2(G?Z(S/
M__](@_@##X9`^O__2(UT`_R_/59``+D%````_/.F3`]$X^DE^O__NC@```!(
M8_@Q]BG"2(V\/$B!``!(8]+HF\W__^EX_?__@+PD$@$``$$/A1K[__^`O"03
M`0``0P^%#/O__X"\)!0!``!(#X7^^O__@+PD%0$``$4/A?#Z__^+?"0<N@(`
M``!(Q\;&____Z(G-__^+?"0<2(VT)!`!``"Z*0```.@#S___3(V$)!`!``!!
MN7960`#IU_[__V9F9I!!5K\^54``055!5%532('L$`0``,8%?7<0``%(BP4>
M=Q``2(F$)`@$```QP.B?Y___2(7`=`F`.#$/A-L!```QP.B:[O__N@L```"^
M`0```+]P5D``Z)+-__](A<`/A(,````Q[8,]M'L0``%(BT`03(M@*'Y?NP@`
M``#K+69FD$B+=Q!(BP6=>Q``2(L\&.CHS/__A<!U/8/%`4B#PPB-10$Y!7A[
M$`!^*S'2B>Y,B>?H!L[__TB%P'0:2(LX]D<-!'6\,?:Z`@```.C,RO__2(G&
MZZ^+%45[$`"-0O\YZ`^$#@$``+H$````O@$```"_=59``.CRS/__2(7`2(G#
M=")(BT`0OG=60`!(BSCH><O__TB+0Q!(BSCV1PY`#X4'`0``N@0```"^`0``
M`+^654``Z+3,__](A<!(B<-T)S'`OW=50`#HA.;__TB%P$B)P@^$"`$``$B+
M0Q!(B=9(BSCH)<O__S'`OUI50`#&!2-V$```2,<%N'40``````#H2^;__TB%
MP$B)!8EZ$``/A*4```"^P`$``$B)Q^AJS/__A<!U)4B+A"0(!```2#,%BW40
M``^%'P$``$B!Q!`$``!;74%<05U!7L.#^!%TUH/X_W31B<%(BP5*>A``2(L5
M,WH0`+_P5T``2(LP,<#HB,G__X/J`0^.Z?[__[L!````3(GG@\,!Z-_)__\Y
M'0UZ$`!_[>G,_O__@'@!`&:0#X0@_O__Z13^__]F9I!FD.C'R?__Z>K^__](
MBSWG>1``Z(KS__](A<!(B07(>1``#X6/````OZ!70`#H',G__TB+!<%Y$`"Z
M_P,``$B)YK]\5D``3(LP2(M#$$R+*.B9S/__A<")PGXX@^H!2&/J@#PL`'5`
MA=)^*$B)ZKXO````2(GGZ*/)__](A<!T$TB)ZDB)YDR)[^APS/__Z:;^__],
MB?9,B>_HP,G__V9F9I#IDO[__TACZ.N_9F:09F:0Z*?+__](BT,02(LM.'D0
M`$B+./9'#01T.DB+?Q!(B>[HI\C__XG%2(M#$$B+./9'#01T,$B+1Q!(B<)(
MBP4&>1``B>F_R%=``$B+,#'`Z$G(__^Z`@```#'VZ%W(__](B<?KN;H"````
M,?;H3,C__^O&9F9FD&9F9I!F9I!F9I"ZCU9``+X<'D``OYE60`#I*,G__V9F
M9I!F9F:09F9FD$B#[`CHU____[EV5D``13'`OI!00`!(B<J_M59``$B#Q`CI
M9<C__Y"0D)"0D)"0D%5(B>532(/L"$B+!4!Q$`!(@_C_=!4QV__02(N#B,50
M`$B#ZPA(@_C_=>U(@\0(6\G#D)!(@^P(Z!/,__](@\0(PP```````"1&<F5E
M0E-$.B!R96QE87-E+S@N,BXP+VQI8B]C<W4O86UD-C0O8W)T:2Y3(#$R-S(U
M,B`R,#`T+3`S+3(Q(#`Q.C,Y.C`Q6B!P971E<B`D`%!!4E]#3$5!3@`N+@`E
M<R\E<P`O<')O8R\E:2\E<P!,24)0051(`$193$1?3$E"4D%265]0051(`%-(
M3$E"7U!!5$@`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%2
M7T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P
M87(M`"UE`"TM`%5315(`55-%4DY!344`4UE35$5-`"4P,G@`5$5-4$1)4@!4
M35``+W9A<B]T;7`O`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`
M+W!R;V,O8W5R<')O8R]F:6QE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`.@``````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````"U60```````RE9`
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@
M>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y```````````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````(R$O=7-R
M+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S
M="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U
M<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@
M("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C
M($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A
M8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S
M=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN
M9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y
M<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N
M;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T
M86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U
M;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N
M;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O
M;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT
M('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG
M('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@
M("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.
M3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M
M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*
M("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@
M("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD
M*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF
M:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!
M4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%2
M7T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS
M92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F
M<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T
M:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*
M("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T
M:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(
M+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE
M<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M
M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0[
M"@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*
M("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@
M("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L
M;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@
M(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@
M("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@
M("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M
M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@
M("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@
M("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE
M)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@
M/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@
M("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@
M("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@
M(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@
M("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD
M:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*
M("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D
M9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@
M("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L
M;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@
M;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I
M;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z
M.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@
M("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE
M(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C
M(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@
M("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@
M("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F
M;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@
M("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@
M("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*
M("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A
M<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U
M<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@
M<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F
M<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H
M92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF
M="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!
M4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@
M)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2![
M"B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@
M("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D
M;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2![
M"B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@
M("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I
M('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@
M(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I
M;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P
M<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM[
M"FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R
M97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D
M>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY
M("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O
M7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@
M86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@
M:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P
M87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@
M("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q0
M05(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O
M=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@
M("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@
M,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@
M("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA
M<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E
M="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@
M("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D
M+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D
M=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO
M9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@
M("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*
M("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@
M("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@
M("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@
M("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T
M;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN
M9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S
M<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET
M:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M
M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N
M9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM
M(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD
M+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@
M("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@
M("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@
M("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@
M("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N
M9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@
M(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@
M("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H
M4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@
M("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F
M:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I
M.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@
M("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@
M("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@
M("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@
M("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D
M8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO
M=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@
M("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E
M.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*
M?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A
M8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!
M4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@
M<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@
M("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@
M("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M
M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN
M<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]
M?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@[
M"B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*
M("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*
M("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@
M(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q
M=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T
M97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P
M<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI
M=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U
M8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R
M96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@
M<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@
M("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@
M("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@
M("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@
M)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*
M("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@
M("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@
M<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*
M("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S
M=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F
M:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@
M)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D
M97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL
M:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`
M=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@
M<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*
M("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE
M*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE
M.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]
M"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@
M("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I
M9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@
M("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N
M86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!0
M5T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@
M("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@
M("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?
M:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@
M("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@
M("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*
M("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@
M("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@
M('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S
M8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*
M(VQI;F4@,3`Q,0H*7U]%3D1?7PH```````````````````#`0R1&<F5E0E-$
M.B!R96QE87-E+S@N,BXP+VQI8B]C<W4O86UD-C0O8W)T;BY3(#$R-S(U,B`R
M,#`T+3`S+3(Q(#`Q.C,Y.C`Q6B!P971E<B`D``````$;`SO8"Q``&0```*1K
M___T"Q``M&S__QP,$`#T;/__-`P0`.2"__]D#!``Q(/__XP,$``4A/__K`P0
M`#2$___$#!``A(3__]P,$`"DA/__]`P0`'2%__\,#1``Q(;__RP-$``4A___
M3`T0`.2'__]L#1``](?__X0-$``$BO__O`T0`"2+___T#1``Y(S__PP.$``4
MC?__)`X0``2.__]$#A``=([__UP.$`!DD/__?`X0`!22__^T#A``1)S__^P.
M$`"DG___'`\0`,2?__\T#Q``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=E9``````````````````*C%4```````.%A```````#_
M____`````!0``````````7I2``%X$`$##`<(D`$``"0````<````\!]``)P`
M````00X0A@)##09"C0-+@P6,!``````````4````1``````A0``T````````
M```````L````7````$`A0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"1`XP
M1PZX!(,&```D````C````#`W0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`````
M````'````+0````0.$``3P````!!#A!!#AB#`X8"1PXP```4````U````&`X
M0``5`````$0.(``````4````[````(`X0`!-`````$0.$``````4````!`$`
M`-`X0``>`````$0.$``````4````'`$``/`X0`#"`````$@.$(,"```<````
M-`$``,`Y0`!"`0```$J#!HP$60ZP`8X"C0.&!1P```!4`0``$#M``$\`````
M00X0@P)'#I`!````````'````'0!``!@.T``R0````!6#L`0C`*&`X,$````
M```4````E`$``#`\0``%```````````````T````K`$``$`\0``%`@```$(.
M$$0.&(X#CP)%#B!"#BA!#C"&!HP%C01$#CA$#E"#!P```````#0```#D`0``
M4#Y``!<!````0@X00@X8C@./`D4.($(.*(P%C01'#C!!#CA$#H`!@P>&!@``
M````%````!P"``!P/T``O@$```!$#D``````%````#0"```P04``(@````!$
M#A``````'````$P"``!@04``X@````!!#A!!#AB#`X8"1PX@```4````;`(`
M`%!"0`!M`````$X.((8"@P,<````A`(``,!"0`#P`0```$$.$$0.,(,"````
M`````#0```"D`@``L$1``*P!````0@X00@X80@X@0@XHC`6-!(X#CP))#C!!
M#CB#!X8&2@[@"0``````-````-P"``!@1D``+`H```!"#A"/`DH.&$(.($(.
M*$$.,$$..$<.H(0"@P>&!HP%C02.`P`````L````%`,``)!00`!2`P```$(.
M$$<.&$(.($$.*$$.,$<.P`B#!H8%C`2-`XX"```4````1`,``/!30``4````
M```````````4````7`,``!!40``G`````$0.$`````````````````$`````
M`````0`````````!`````````"P"`````````0`````````V`@````````$`
M````````1`(````````!`````````%$"`````````0````````!U`@``````
M``\`````````I0,````````,`````````.@;0```````#0````````!T5$``
M``````0`````````^`%````````%`````````.@.0```````!@`````````H
M!4````````H`````````RP0````````+`````````!@`````````%0``````
M``````````````,`````````N,50```````"`````````-`%````````%```
M```````'`````````!<`````````&!9````````'`````````,@40```````
M"`````````!0`0````````D`````````&`````````#^__]O`````(@40```
M````____;P`````"`````````/#__V\`````M!-`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M_____P``````````__________\`````````````````````H,-0````````
M````````````````````$AQ````````B'$```````#(<0```````0AQ`````
M``!2'$```````&(<0```````<AQ```````""'$```````)(<0```````HAQ`
M``````"R'$```````,(<0```````TAQ```````#B'$```````/(<0```````
M`AU````````2'4```````"(=0```````,AU```````!"'4```````%(=0```
M````8AU```````!R'4```````((=0```````DAU```````"B'4```````+(=
M0```````PAU```````#2'4```````.(=0```````\AU````````"'D``````
M`!(>0```````(AY````````R'D```````$(>0```````4AY```````!B'D``
M`````'(>0```````@AY```````"2'D```````*(>0```````LAY```````#"
M'D```````-(>0```````XAY```````#R'D````````(?0```````$A]`````
M```B'T```````#(?0```````0A]```````!2'T```````&(?0```````<A]`
M``````""'T```````)(?0```````HA]```````"R'T```````,(?0```````
MTA]```````#B'T`````````D1G)E94)31#H@<F5L96%S92\X+C(N,"]L:6(O
M8W-U+V-O;6UO;B]C<G1B<F%N9"YC(#$W-#(U,2`R,#`W+3$R+3`T(#$R.C$X
M.C0S6B!K:6(@)``D1G)E94)31#H@<F5L96%S92\X+C(N,"]L:6(O8W-U+V%M
M9#8T+V-R=#$N8R`Q-3$P-S(@,C`P-2TQ,"TP-R`R,CHQ,SHQ-UH@8F1E("0`
M1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'0T,Z("A'
M3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR
M+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W
M,#<Q.2`@6T9R965"4T1=```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV
M97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F1A=&$`+F5H7V9R86UE`"YD>6YA
M;6EC`"YC=&]R<P`N9'1O<G,`+FIC<@`N9V]T`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M```````````````````````````````+`````0````(`````````R`%`````
M``#(`0```````!4````````````````````!````````````````````$P``
M``<````"`````````.`!0```````X`$````````8````````````````````
M!````````````````````"$````%`````@````````#X`4```````/@!````
M````+`,````````$``````````@`````````!``````````G````"P````(`
M````````*`5````````H!0```````,`)````````!0````$````(````````
M`!@`````````+P````,````"`````````.@.0```````Z`X```````#+!```
M`````````````````0```````````````````#<```#___]O`@````````"T
M$T```````+03````````T``````````$``````````(``````````@``````
M``!$````_O__;P(`````````B!1```````"(%````````$``````````!0``
M``(````(````````````````````4P````0````"`````````,@40```````
MR!0```````!0`0````````0`````````"``````````8`````````%T````$
M`````@`````````8%D```````!@6````````T`4````````$````"P````@`
M````````&`````````!G`````0````8`````````Z!M```````#H&P``````
M`!,````````````````````$````````````````````8@````$````&````
M`````/P;0```````_!L```````#P`P``````````````````!``````````0
M`````````&T````!````!@````````#P'T```````/`?````````A#0`````
M`````````````!````````````````````!S`````0````8`````````=%1`
M``````!T5`````````X````````````````````$````````````````````
M>0````$````"`````````(A40```````B%0```````#!7P``````````````
M````"````````````````````($````!`````@````````!,M$```````$RT
M````````U`````````````````````0```````````````````"/`````0``
M``,``````````,!0````````P````````"0````````````````````(````
M````````````````E0````$````"`````````"C`4```````*,````````!T
M`P``````````````````"````````````````````)\````&`````P``````
M``"@PU```````*##````````\`$````````%``````````@`````````$```
M``````"H`````0````,`````````D,50``````"0Q0```````!``````````
M```````````(````````````````````KP````$````#`````````*#%4```
M````H,4````````0````````````````````"````````````````````+8`
M```!`````P````````"PQ5```````+#%````````"```````````````````
M``@```````````````````"[`````0````,`````````N,50``````"XQ0``
M``````@"```````````````````(``````````@`````````P`````@````#
M`````````,#'4```````P,<````````(!0``````````````````(```````
M`````````````,4````!`````````````````````````,#'````````.P$`
M``````````````````$````````````````````!`````P``````````````
M``````````#[R````````,X````````````````````!````````````````
#````
